/*
 * The contents of this file are subject to the terms
 * of the Common Development and Distribution License
 * (the "License").  You may not use this file except
 * in compliance with the License.
 *
 * You can obtain a copy of the license at
 * glassfish/bootstrap/legal/CDDLv1.0.txt or
 * https://glassfish.dev.java.net/public/CDDLv1.0.html.
 * See the License for the specific language governing
 * permissions and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL
 * HEADER in each file and include the License file at
 * glassfish/bootstrap/legal/CDDLv1.0.txt.  If applicable,
 * add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your
 * own identifying information: Portions Copyright [yyyy]
 * [name of copyright owner]
 */
package client;

import javax.persistence.EntityManager;
import javax.persistence.Persistence;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Query;

import java.util.Collection;
import java.util.List;

import entity.*;

/**
 * @author Marina Vatkina
 */
public class Client {

    private static EntityManagerFactory emf;
    private static EntityManager em;

    public static void main(String[] args) {

        emf = Persistence.createEntityManagerFactory("pu1");
        em = emf.createEntityManager();

        em.getTransaction().begin();

        // Create and persist all entity
        System.out.println("Inserting Customer... " + testInsert());

        em.getTransaction().commit();

        // Begin transaction
        em.getTransaction().begin();

        // Deleting entity
        System.out.println("Finding Customer...");
        Customer c = findCustomer("Joe Smith");
        System.out.println("Deleting Customer... " + testDelete(c));

        // Close this EntityManager
        em.close();
    }

    private static String testInsert() {

        // Create new customer
        Customer customer0 = new Customer();
        customer0.setId(1);
        customer0.setName("Joe Smith");
        Character[] lobCharacter = new Character[100];
        for (int i = 0; i < 10; i++) {
            lobCharacter[i] = 'a';
        }
        customer0.setCharArray(lobCharacter);

        // Persist the customer
        em.persist(customer0);

        return "OK";
    }
        

    private static String testDelete(Customer c) {

        // Merge the customer to the new persistence context
        Customer c0 = em.merge(c);

        // Delete all records.
        em.remove(c0);

        return "OK";
    }


    private static Customer findCustomer(String name) {

        Query q = em.createQuery("select c from Customer c where c.name = :name");
        q.setParameter("name", name);
        return (Customer)q.getSingleResult();

    }

}
